====
Rend
====

Rend is the renderer collection used by pop and pop derived projects.
It allows for text files of multiple types to be read and rendered into
consistent data structures. These files also get the benefit of having
access to specific components of the hub.
